%define major   1
%define libname %mklibname fdt %{major}
%define devname %mklibname fdt -d

%global with_mingw 0

%if 0%{?mageia}
%global with_mingw 1
%endif

Name:          dtc
Version:       1.6.1
Release:       %mkrel 5
Summary:       Device Tree Compiler
Group:         Development/Tools
License:       GPLv2+
URL:           https://devicetree.org/

Source0:       https://www.kernel.org/pub/software/utils/%{name}/%{name}-%{version}.tar.xz

BuildRequires: gcc make
BuildRequires: flex bison swig
BuildRequires: python3-devel python3-setuptools

%if %{with_mingw}
BuildRequires: mingw32-filesystem >= 95
BuildRequires: mingw32-gcc-c++

BuildRequires: meson

BuildRequires: mingw64-filesystem >= 95
BuildRequires: mingw64-gcc-c++
%endif

%description
Devicetree is a data structure for describing hardware. Rather than hard coding
every detail of a device into an operating system, many aspects of the hardware
can be described in a data structure that is passed to the operating system at
boot time. The devicetree is used by OpenFirmware, OpenPOWER Abstraction Layer
(OPAL), Power Architecture Platform Requirements (PAPR) and in the standalone
Flattened Device Tree (FDT) form.

%package -n %{libname}
Summary: Device tree library
Group: System/Libraries

%description -n %{libname}
libfdt is a library to process Open Firmware style device trees on various
architectures.

%package -n %{devname}
Summary: Development headers for device tree library
Group: Development/C
Requires: %{libname} = %{version}-%{release}
Provides: libfdt-devel = %{version}-%{release}

%description -n %{devname}
This package provides development files for libfdt

%package -n python3-libfdt
Summary: Python 3 bindings for device tree library
%{?python_provide:%python_provide python3-libfdt}
Requires: %{name} = %{version}-%{release}

%description -n python3-libfdt
This package provides python3 bindings for libfdt

%if %{with_mingw}
%package -n mingw32-libfdt
Summary: MinGW Device tree library
BuildArch: noarch

%description -n mingw32-libfdt
libfdt is a library to process Open Firmware style device trees on various
architectures.

%package -n mingw64-libfdt
Summary: MinGW Device tree library
BuildArch: noarch

%description -n mingw64-libfdt
libfdt is a library to process Open Firmware style device trees on various
architectures.

%{?mingw_debug_package}
%endif

%prep
%autosetup -p1

%build
%define _legacy_common_support 1
%{make_build} EXTRA_CFLAGS="%{build_cflags}" LDFLAGS="%{build_ldflags}"

%if %{with_mingw}
%mingw_meson -Dtools=false
%mingw_ninja
%endif

%install
%{make_install} DESTDIR=%{buildroot} PREFIX=%{buildroot}/%{_prefix} \
                LIBDIR=%{_libdir} BINDIR=%{_bindir} INCLUDEDIR=%{_includedir}
find %{buildroot} -type f -name "*.a" -delete

# we don't want ftdump and it conflicts with freetype-demos, so drop it (rhbz 797805)
rm -f %{buildroot}%{_bindir}/ftdump

%if %{with_mingw}
%mingw_ninja_install
%mingw_debug_install_post
%endif

%files
%license GPL
%doc Documentation/manual.txt
%{_bindir}/*

%files -n %{libname}
%license GPL
%{_libdir}/libfdt-%{version}.so
%{_libdir}/libfdt.so.%{major}

%files -n %{devname}
%{_libdir}/libfdt.so
%{_includedir}/*

%files -n python3-libfdt
%{python3_sitearch}/*

%if %{with_mingw}
%files -n mingw32-libfdt
%license GPL
%{mingw32_bindir}/libfdt-1.dll
%{mingw32_includedir}/*fdt*.h
%{mingw32_libdir}/libfdt.dll.a
%{mingw32_libdir}/pkgconfig/libfdt.pc

%files -n mingw64-libfdt
%license GPL
%{mingw64_bindir}/libfdt-1.dll
%{mingw64_includedir}/*fdt*.h
%{mingw64_libdir}/libfdt.dll.a
%{mingw64_libdir}/pkgconfig/libfdt.pc
%endif



%changelog
* Sun Nov 06 2022 tv <tv> 1.6.1-5.mga9
+ Revision: 1904023
- Add mingw sub-packages

* Sat Mar 26 2022 umeabot <umeabot> 1.6.1-4.mga9
+ Revision: 1827819
- Mageia 9 Mass Rebuild

* Tue Feb 22 2022 tv <tv> 1.6.1-3.mga9
+ Revision: 1782759
- Rebuild for python-3.10

* Sat Oct 23 2021 tv <tv> 1.6.1-2.mga9
+ Revision: 1752749
- Update to 1.6.1

* Sat Mar 27 2021 tv <tv> 1.5.1-4.mga9
+ Revision: 1710861
- rebuild for python 3.9

* Sun Jul 05 2020 joequant <joequant> 1.5.1-3.mga8
+ Revision: 1602131
- bump
- build gcc10

* Sun Feb 16 2020 umeabot <umeabot> 1.5.1-2.mga8
+ Revision: 1532213
- Mageia 8 Mass Rebuild

* Mon Sep 16 2019 tv <tv> 1.5.1-1.mga8
+ Revision: 1442248
- new release
- use our build flags during build
- switch for python3 for building

* Sun Sep 23 2018 umeabot <umeabot> 1.4.6-2.mga7
+ Revision: 1297520
- Mageia 7 Mass Rebuild

* Fri Jun 01 2018 wally <wally> 1.4.6-1.mga7
+ Revision: 1233500
- new version 1.4.6
- sync patches with fedora

* Fri Apr 15 2016 tv <tv> 1.4.1-1.mga6
+ Revision: 1001701
- imported package dtc

